@@ -2,7 +2,6 @@
   # catch an error if it doesn't exist, otherwise return normalized path
   # important for handling relative paths in a rmarkdown::render() context
   if (! dir.exists(x)){
-    .multilog_error(paste0("render_root = ", x, " doesn't exist"))
     stop(paste0("render_root = ", x, " doesn't exist"))
   }
   normalizePath(x, winslash = "/")
@@ -46,14 +45,8 @@ DataPackageR <- function(arg = NULL, deps = TRUE) {
 
   logpath <- file.path(pkg_dir, "inst", "extdata", "Logfiles")
   dir.create(logpath, recursive = TRUE, showWarnings = FALSE)
-  # open a log file
-  LOGFILE <- file.path(logpath, "processing.log")
-  .multilog_setup(LOGFILE)
-  .multilog_thresold(console = INFO, logfile = TRACE)
-  .multilog_trace(paste0("Logging to ", LOGFILE))
   # validate package
   validate_package_skeleton(pkg_dir)
-  .multilog_trace("Processing data")
   # validate datapackager.yml
   ymlconf <- validate_yml(pkg_dir)
   # get vector of R and Rmd files from validated YAML
@@ -90,10 +83,6 @@ DataPackageR <- function(arg = NULL, deps = TRUE) {
     # assign ENVS into dataenv.
     # provide functions in the package to read from it (if deps = TRUE)
     if (deps) assign(x = "ENVS", value = ENVS, dataenv)
-    .multilog_trace(paste0(
-      "Processing ", i, " of ",
-      length(r_files), ": ", r_files[i]
-    ))
     # config file goes in the root render the r and rmd files
     ## First we spin then render if it's an R file
     flag <- FALSE
@@ -137,11 +126,6 @@ DataPackageR <- function(arg = NULL, deps = TRUE) {
     object_tally <- object_tally | objects_to_keep %in% object_names
     already_built <- unique(c(already_built,
                               objects_to_keep[objects_to_keep %in% object_names]))
-    .multilog_trace(paste0(
-      sum(objects_to_keep %in% object_names),
-      " data set(s) created by ",
-      basename(r_files[i])
-    ))
     .done(paste0(
       sum(objects_to_keep %in% object_names),
       " data set(s) created by ",
@@ -191,7 +175,6 @@ DataPackageR <- function(arg = NULL, deps = TRUE) {
   do_doc(pkg_dir, dataenv)
   # copy html files to vignettes
   .ppfiles_mkvignettes(dir = pkg_dir)
-  .multilog_trace("Done")
   return(TRUE)
 }
 
@@ -233,20 +216,16 @@ validate_yml <- function(pkg_dir){
     full.names = TRUE
   )
   if (length(ymlfile) == 0) {
-    .multilog_fatal(paste0("Yaml configuration file not found at ", pkg_dir))
-    stop("exiting", call. = FALSE)
+    stop(paste("Yaml configuration file not found at", pkg_dir))
   }
   ymlconf <- read_yaml(ymlfile)
   # test that the structure of the yaml file is correct!
   if (!"configuration" %in% names(ymlconf)) {
-    .multilog_fatal("YAML is missing 'configuration:' entry")
-    stop("exiting", call. = FALSE)
+    stop("YAML is missing 'configuration:' entry")
   }
   if (!all(c("files", "objects") %in% names(ymlconf$configuration))) {
-    .multilog_fatal("YAML is missing files: and objects: entries")
-    stop("exiting", call. = FALSE)
+    stop("YAML is missing files: and objects: entries")
   }
-  .multilog_trace("Reading yaml configuration")
   # files that have enable: TRUE
   stopifnot("configuration" %in% names(ymlconf))
   stopifnot("files" %in% names(ymlconf[["configuration"]]))
@@ -255,34 +234,25 @@ validate_yml <- function(pkg_dir){
   # object with same name as package causes problems with
   # overwriting documentation files
   if (basename(pkg_dir) %in% ymlconf$configuration$objects){
-    err_msg <- "Data object not allowed to have same name as data package"
-    flog.fatal(err_msg, name = "console")
-    stop(err_msg, call. = FALSE)
+    stop("Data object not allowed to have same name as data package")
   }
   render_root <- .get_render_root(ymlconf)
   .validate_render_root(render_root)
   if (length(get_yml_objects(ymlconf)) == 0) {
-    .multilog_fatal("You must specify at least one data object.")
-    stop("exiting", call. = FALSE)
+    stop("You must specify at least one data object.")
   }
   r_files <- get_yml_r_files(ymlconf)
   if (length(r_files) == 0) {
-    .multilog_fatal("No files enabled for processing!")
-    stop("error", call. = FALSE)
+    stop("No files enabled for processing!")
   }
   if (any(duplicated(r_files))){
-    err_msg <- "Duplicate R files specified in YAML."
-    .multilog_fatal(err_msg)
-    stop(err_msg, call. = FALSE)
+    stop("Duplicate R files specified in YAML.")
   }
   for (file in r_files){
     if (! file.exists(file.path(pkg_dir, 'data-raw', file))){
-      err_msg <- paste("Missing R file specified in YAML:", file)
-      .multilog_fatal(err_msg)
-      stop(err_msg, call. = FALSE)
+      stop(paste("Missing R file specified in YAML:", file))
     }
   }
-  .multilog_trace(paste0("Found ", r_files))
   return(ymlconf)
 }
 
@@ -299,9 +269,7 @@ validate_package_skeleton <- function(pkg_dir){
   dirs <- file.path(pkg_dir, c("R", "inst", "data", "data-raw"))
   for (dir in dirs){
     if (! utils::file_test(dir, op = "-d")){
-      err_msg <- paste("Missing required subdirectory", dir)
-      .multilog_fatal(err_msg)
-      stop(err_msg)
+      stop(paste("Missing required subdirectory", dir))
     }
   }
   # check we can read a DESCRIPTION file
@@ -319,12 +287,10 @@ validate_description <- function(pkg_dir){
   d <- desc::desc(pkg_dir)
   dv <- d$get('DataVersion')
   if (is.na(dv)) {
-    err_msg <- paste0(
+    stop(paste(
       "DESCRIPTION file must have a DataVersion",
-      " line. i.e. DataVersion: 0.2.0"
-    )
-    .multilog_fatal(err_msg)
-    stop(err_msg, call. = FALSE)
+      "line. i.e. DataVersion: 0.2.0"
+    ))
   }
   validate_DataVersion(dv)
   d
@@ -391,17 +357,10 @@ do_digests <- function(pkg_dir, dataenv) {
   same_digests <- .compare_digests(old_data_digest, new_data_digest)
   if ((! same_digests) && check_new_DataVersion == "higher"){
     # not sure how this would actually happen
-    err_msg <- 'Digest(s) differ but DataVersion had already been incremented'
-    .multilog_fatal(err_msg)
-    stop(err_msg, call. = FALSE)
+    stop('Digest(s) differ but DataVersion had already been incremented')
   }
   if (same_digests && check_new_DataVersion == "equal") {
     can_write <- TRUE
-    .multilog_trace(paste0(
-      "Processed data sets match ",
-      "existing data sets at version ",
-      new_data_digest[["DataVersion"]]
-    ))
   } else if ((! same_digests) && check_new_DataVersion == "equal") {
     updated_version <- .increment_data_version(
       pkg_desc,
@@ -417,26 +376,13 @@ do_digests <- function(pkg_dir, dataenv) {
     pkg_desc <- updated_version$pkg_description
     new_data_digest <- updated_version$new_data_digest
     can_write <- TRUE
-    .multilog_trace(paste0(
-      "Data has been updated and DataVersion ",
-      "string incremented automatically to ",
-      new_data_digest[["DataVersion"]]
-    ))
   } else if (same_digests && check_new_DataVersion == "higher") {
     # edge case that shouldn't happen
     # but we test for it in the test suite
     can_write <- TRUE
-    .multilog_trace(paste0(
-      "Data hasn't changed but the ",
-      "DataVersion has been bumped."
-    ))
   } else if (check_new_DataVersion == "lower" && same_digests) {
     # edge case that shouldn't happen but
     # we test for it in the test suite.
-    .multilog_trace(paste0(
-      "New DataVersion is less than ",
-      "old but data are unchanged"
-    ))
     new_data_digest <- old_data_digest
     pkg_desc$set('DataVersion',
                  validate_DataVersion(new_data_digest[["DataVersion"]])
@@ -521,12 +467,6 @@ do_doc <- function(pkg_dir, dataenv) {
   writeLines(Reduce(c, doc_parsed),
              file.path(pkg_dir, "R", paste0(pkg_name, ".R"))
   )
-  .multilog_trace(
-    paste0(
-      "Copied documentation to ",
-      file.path(pkg_dir, "R", paste0(pkg_name, ".R"))
-    )
-  )
   # TODO test that we have documented
   # everything successfully and that all files
   # have been parsed successfully
@@ -789,7 +729,6 @@ document <- function(path = ".", install = FALSE, ...) {
     to = file.path(path, "R", docfile),
     overwrite = TRUE
   )
-  .multilog_trace("Rebuilding data package documentation.")
   local({
     on.exit({
       if (basename(path) %in% names(utils::sessionInfo()$otherPkgs)){
